# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LiveTvListingsProviderInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'setup_url': 'str',
        'id': 'str',
        'type': 'str',
        'username': 'str',
        'password': 'str',
        'listings_id': 'str',
        'zip_code': 'str',
        'country': 'str',
        'path': 'str',
        'enabled_tuners': 'list[str]',
        'enable_all_tuners': 'bool',
        'news_categories': 'list[str]',
        'sports_categories': 'list[str]',
        'kids_categories': 'list[str]',
        'movie_categories': 'list[str]',
        'channel_mappings': 'list[NameValuePair]',
        'movie_prefix': 'str',
        'preferred_language': 'str',
        'user_agent': 'str',
        'data_version': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'setup_url': 'SetupUrl',
        'id': 'Id',
        'type': 'Type',
        'username': 'Username',
        'password': 'Password',
        'listings_id': 'ListingsId',
        'zip_code': 'ZipCode',
        'country': 'Country',
        'path': 'Path',
        'enabled_tuners': 'EnabledTuners',
        'enable_all_tuners': 'EnableAllTuners',
        'news_categories': 'NewsCategories',
        'sports_categories': 'SportsCategories',
        'kids_categories': 'KidsCategories',
        'movie_categories': 'MovieCategories',
        'channel_mappings': 'ChannelMappings',
        'movie_prefix': 'MoviePrefix',
        'preferred_language': 'PreferredLanguage',
        'user_agent': 'UserAgent',
        'data_version': 'DataVersion'
    }

    def __init__(self, name=None, setup_url=None, id=None, type=None, username=None, password=None, listings_id=None, zip_code=None, country=None, path=None, enabled_tuners=None, enable_all_tuners=None, news_categories=None, sports_categories=None, kids_categories=None, movie_categories=None, channel_mappings=None, movie_prefix=None, preferred_language=None, user_agent=None, data_version=None):  # noqa: E501
        """LiveTvListingsProviderInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._setup_url = None
        self._id = None
        self._type = None
        self._username = None
        self._password = None
        self._listings_id = None
        self._zip_code = None
        self._country = None
        self._path = None
        self._enabled_tuners = None
        self._enable_all_tuners = None
        self._news_categories = None
        self._sports_categories = None
        self._kids_categories = None
        self._movie_categories = None
        self._channel_mappings = None
        self._movie_prefix = None
        self._preferred_language = None
        self._user_agent = None
        self._data_version = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if setup_url is not None:
            self.setup_url = setup_url
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if listings_id is not None:
            self.listings_id = listings_id
        if zip_code is not None:
            self.zip_code = zip_code
        if country is not None:
            self.country = country
        if path is not None:
            self.path = path
        if enabled_tuners is not None:
            self.enabled_tuners = enabled_tuners
        if enable_all_tuners is not None:
            self.enable_all_tuners = enable_all_tuners
        if news_categories is not None:
            self.news_categories = news_categories
        if sports_categories is not None:
            self.sports_categories = sports_categories
        if kids_categories is not None:
            self.kids_categories = kids_categories
        if movie_categories is not None:
            self.movie_categories = movie_categories
        if channel_mappings is not None:
            self.channel_mappings = channel_mappings
        if movie_prefix is not None:
            self.movie_prefix = movie_prefix
        if preferred_language is not None:
            self.preferred_language = preferred_language
        if user_agent is not None:
            self.user_agent = user_agent
        if data_version is not None:
            self.data_version = data_version

    @property
    def name(self):
        """Gets the name of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The name of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LiveTvListingsProviderInfo.


        :param name: The name of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def setup_url(self):
        """Gets the setup_url of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The setup_url of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._setup_url

    @setup_url.setter
    def setup_url(self, setup_url):
        """Sets the setup_url of this LiveTvListingsProviderInfo.


        :param setup_url: The setup_url of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._setup_url = setup_url

    @property
    def id(self):
        """Gets the id of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The id of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LiveTvListingsProviderInfo.


        :param id: The id of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The type of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LiveTvListingsProviderInfo.


        :param type: The type of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def username(self):
        """Gets the username of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The username of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this LiveTvListingsProviderInfo.


        :param username: The username of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The password of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this LiveTvListingsProviderInfo.


        :param password: The password of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def listings_id(self):
        """Gets the listings_id of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The listings_id of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._listings_id

    @listings_id.setter
    def listings_id(self, listings_id):
        """Sets the listings_id of this LiveTvListingsProviderInfo.


        :param listings_id: The listings_id of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._listings_id = listings_id

    @property
    def zip_code(self):
        """Gets the zip_code of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The zip_code of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """Sets the zip_code of this LiveTvListingsProviderInfo.


        :param zip_code: The zip_code of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._zip_code = zip_code

    @property
    def country(self):
        """Gets the country of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The country of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this LiveTvListingsProviderInfo.


        :param country: The country of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def path(self):
        """Gets the path of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The path of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this LiveTvListingsProviderInfo.


        :param path: The path of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def enabled_tuners(self):
        """Gets the enabled_tuners of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The enabled_tuners of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._enabled_tuners

    @enabled_tuners.setter
    def enabled_tuners(self, enabled_tuners):
        """Sets the enabled_tuners of this LiveTvListingsProviderInfo.


        :param enabled_tuners: The enabled_tuners of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[str]
        """

        self._enabled_tuners = enabled_tuners

    @property
    def enable_all_tuners(self):
        """Gets the enable_all_tuners of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The enable_all_tuners of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enable_all_tuners

    @enable_all_tuners.setter
    def enable_all_tuners(self, enable_all_tuners):
        """Sets the enable_all_tuners of this LiveTvListingsProviderInfo.


        :param enable_all_tuners: The enable_all_tuners of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: bool
        """

        self._enable_all_tuners = enable_all_tuners

    @property
    def news_categories(self):
        """Gets the news_categories of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The news_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._news_categories

    @news_categories.setter
    def news_categories(self, news_categories):
        """Sets the news_categories of this LiveTvListingsProviderInfo.


        :param news_categories: The news_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[str]
        """

        self._news_categories = news_categories

    @property
    def sports_categories(self):
        """Gets the sports_categories of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The sports_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._sports_categories

    @sports_categories.setter
    def sports_categories(self, sports_categories):
        """Sets the sports_categories of this LiveTvListingsProviderInfo.


        :param sports_categories: The sports_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[str]
        """

        self._sports_categories = sports_categories

    @property
    def kids_categories(self):
        """Gets the kids_categories of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The kids_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._kids_categories

    @kids_categories.setter
    def kids_categories(self, kids_categories):
        """Sets the kids_categories of this LiveTvListingsProviderInfo.


        :param kids_categories: The kids_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[str]
        """

        self._kids_categories = kids_categories

    @property
    def movie_categories(self):
        """Gets the movie_categories of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The movie_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._movie_categories

    @movie_categories.setter
    def movie_categories(self, movie_categories):
        """Sets the movie_categories of this LiveTvListingsProviderInfo.


        :param movie_categories: The movie_categories of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[str]
        """

        self._movie_categories = movie_categories

    @property
    def channel_mappings(self):
        """Gets the channel_mappings of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The channel_mappings of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: list[NameValuePair]
        """
        return self._channel_mappings

    @channel_mappings.setter
    def channel_mappings(self, channel_mappings):
        """Sets the channel_mappings of this LiveTvListingsProviderInfo.


        :param channel_mappings: The channel_mappings of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: list[NameValuePair]
        """

        self._channel_mappings = channel_mappings

    @property
    def movie_prefix(self):
        """Gets the movie_prefix of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The movie_prefix of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._movie_prefix

    @movie_prefix.setter
    def movie_prefix(self, movie_prefix):
        """Sets the movie_prefix of this LiveTvListingsProviderInfo.


        :param movie_prefix: The movie_prefix of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._movie_prefix = movie_prefix

    @property
    def preferred_language(self):
        """Gets the preferred_language of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The preferred_language of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._preferred_language

    @preferred_language.setter
    def preferred_language(self, preferred_language):
        """Sets the preferred_language of this LiveTvListingsProviderInfo.


        :param preferred_language: The preferred_language of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._preferred_language = preferred_language

    @property
    def user_agent(self):
        """Gets the user_agent of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The user_agent of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this LiveTvListingsProviderInfo.


        :param user_agent: The user_agent of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    @property
    def data_version(self):
        """Gets the data_version of this LiveTvListingsProviderInfo.  # noqa: E501


        :return: The data_version of this LiveTvListingsProviderInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_version

    @data_version.setter
    def data_version(self, data_version):
        """Sets the data_version of this LiveTvListingsProviderInfo.


        :param data_version: The data_version of this LiveTvListingsProviderInfo.  # noqa: E501
        :type: str
        """

        self._data_version = data_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiveTvListingsProviderInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveTvListingsProviderInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LiveTvLiveTvInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_enabled': 'bool',
        'enabled_users': 'list[str]'
    }

    attribute_map = {
        'is_enabled': 'IsEnabled',
        'enabled_users': 'EnabledUsers'
    }

    def __init__(self, is_enabled=None, enabled_users=None):  # noqa: E501
        """LiveTvLiveTvInfo - a model defined in Swagger"""  # noqa: E501
        self._is_enabled = None
        self._enabled_users = None
        self.discriminator = None
        if is_enabled is not None:
            self.is_enabled = is_enabled
        if enabled_users is not None:
            self.enabled_users = enabled_users

    @property
    def is_enabled(self):
        """Gets the is_enabled of this LiveTvLiveTvInfo.  # noqa: E501

        A value indicating whether this instance is enabled.  # noqa: E501

        :return: The is_enabled of this LiveTvLiveTvInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this LiveTvLiveTvInfo.

        A value indicating whether this instance is enabled.  # noqa: E501

        :param is_enabled: The is_enabled of this LiveTvLiveTvInfo.  # noqa: E501
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def enabled_users(self):
        """Gets the enabled_users of this LiveTvLiveTvInfo.  # noqa: E501

        The enabled users.  # noqa: E501

        :return: The enabled_users of this LiveTvLiveTvInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._enabled_users

    @enabled_users.setter
    def enabled_users(self, enabled_users):
        """Sets the enabled_users of this LiveTvLiveTvInfo.

        The enabled users.  # noqa: E501

        :param enabled_users: The enabled_users of this LiveTvLiveTvInfo.  # noqa: E501
        :type: list[str]
        """

        self._enabled_users = enabled_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiveTvLiveTvInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveTvLiveTvInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PackageVersionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'guid': 'str',
        'version_str': 'str',
        'classification': 'PackageVersionClass',
        'description': 'str',
        'required_version_str': 'str',
        'source_url': 'str',
        'checksum': 'str',
        'target_filename': 'str',
        'info_url': 'str',
        'runtimes': 'str',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'name': 'name',
        'guid': 'guid',
        'version_str': 'versionStr',
        'classification': 'classification',
        'description': 'description',
        'required_version_str': 'requiredVersionStr',
        'source_url': 'sourceUrl',
        'checksum': 'checksum',
        'target_filename': 'targetFilename',
        'info_url': 'infoUrl',
        'runtimes': 'runtimes',
        'timestamp': 'timestamp'
    }

    def __init__(self, name=None, guid=None, version_str=None, classification=None, description=None, required_version_str=None, source_url=None, checksum=None, target_filename=None, info_url=None, runtimes=None, timestamp=None):  # noqa: E501
        """PackageVersionInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._guid = None
        self._version_str = None
        self._classification = None
        self._description = None
        self._required_version_str = None
        self._source_url = None
        self._checksum = None
        self._target_filename = None
        self._info_url = None
        self._runtimes = None
        self._timestamp = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if guid is not None:
            self.guid = guid
        if version_str is not None:
            self.version_str = version_str
        if classification is not None:
            self.classification = classification
        if description is not None:
            self.description = description
        if required_version_str is not None:
            self.required_version_str = required_version_str
        if source_url is not None:
            self.source_url = source_url
        if checksum is not None:
            self.checksum = checksum
        if target_filename is not None:
            self.target_filename = target_filename
        if info_url is not None:
            self.info_url = info_url
        if runtimes is not None:
            self.runtimes = runtimes
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def name(self):
        """Gets the name of this PackageVersionInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PackageVersionInfo.

        The name.  # noqa: E501

        :param name: The name of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def guid(self):
        """Gets the guid of this PackageVersionInfo.  # noqa: E501

        The guid.  # noqa: E501

        :return: The guid of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this PackageVersionInfo.

        The guid.  # noqa: E501

        :param guid: The guid of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def version_str(self):
        """Gets the version_str of this PackageVersionInfo.  # noqa: E501

        The version STR.  # noqa: E501

        :return: The version_str of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_str

    @version_str.setter
    def version_str(self, version_str):
        """Sets the version_str of this PackageVersionInfo.

        The version STR.  # noqa: E501

        :param version_str: The version_str of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._version_str = version_str

    @property
    def classification(self):
        """Gets the classification of this PackageVersionInfo.  # noqa: E501


        :return: The classification of this PackageVersionInfo.  # noqa: E501
        :rtype: PackageVersionClass
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this PackageVersionInfo.


        :param classification: The classification of this PackageVersionInfo.  # noqa: E501
        :type: PackageVersionClass
        """

        self._classification = classification

    @property
    def description(self):
        """Gets the description of this PackageVersionInfo.  # noqa: E501

        The description.  # noqa: E501

        :return: The description of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PackageVersionInfo.

        The description.  # noqa: E501

        :param description: The description of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def required_version_str(self):
        """Gets the required_version_str of this PackageVersionInfo.  # noqa: E501

        The required version STR.  # noqa: E501

        :return: The required_version_str of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._required_version_str

    @required_version_str.setter
    def required_version_str(self, required_version_str):
        """Sets the required_version_str of this PackageVersionInfo.

        The required version STR.  # noqa: E501

        :param required_version_str: The required_version_str of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._required_version_str = required_version_str

    @property
    def source_url(self):
        """Gets the source_url of this PackageVersionInfo.  # noqa: E501

        The source URL.  # noqa: E501

        :return: The source_url of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_url

    @source_url.setter
    def source_url(self, source_url):
        """Sets the source_url of this PackageVersionInfo.

        The source URL.  # noqa: E501

        :param source_url: The source_url of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._source_url = source_url

    @property
    def checksum(self):
        """Gets the checksum of this PackageVersionInfo.  # noqa: E501

        The source URL.  # noqa: E501

        :return: The checksum of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this PackageVersionInfo.

        The source URL.  # noqa: E501

        :param checksum: The checksum of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._checksum = checksum

    @property
    def target_filename(self):
        """Gets the target_filename of this PackageVersionInfo.  # noqa: E501

        The target filename.  # noqa: E501

        :return: The target_filename of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_filename

    @target_filename.setter
    def target_filename(self, target_filename):
        """Sets the target_filename of this PackageVersionInfo.

        The target filename.  # noqa: E501

        :param target_filename: The target_filename of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._target_filename = target_filename

    @property
    def info_url(self):
        """Gets the info_url of this PackageVersionInfo.  # noqa: E501


        :return: The info_url of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._info_url

    @info_url.setter
    def info_url(self, info_url):
        """Sets the info_url of this PackageVersionInfo.


        :param info_url: The info_url of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._info_url = info_url

    @property
    def runtimes(self):
        """Gets the runtimes of this PackageVersionInfo.  # noqa: E501


        :return: The runtimes of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._runtimes

    @runtimes.setter
    def runtimes(self, runtimes):
        """Sets the runtimes of this PackageVersionInfo.


        :param runtimes: The runtimes of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._runtimes = runtimes

    @property
    def timestamp(self):
        """Gets the timestamp of this PackageVersionInfo.  # noqa: E501


        :return: The timestamp of this PackageVersionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PackageVersionInfo.


        :param timestamp: The timestamp of this PackageVersionInfo.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PackageVersionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageVersionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class VideoMediaTypes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    UNKNOWN = "Unknown"
    COPY = "copy"
    FLV1 = "flv1"
    H263 = "h263"
    H263P = "h263p"
    H264 = "h264"
    HEVC = "hevc"
    MJPEG = "mjpeg"
    MPEG1VIDEO = "mpeg1video"
    MPEG2VIDEO = "mpeg2video"
    MPEG4 = "mpeg4"
    MSVIDEO1 = "msvideo1"
    THEORA = "theora"
    VC1IMAGE = "vc1image"
    VC1 = "vc1"
    VP8 = "vp8"
    VP9 = "vp9"
    WMV1 = "wmv1"
    WMV2 = "wmv2"
    WMV3 = "wmv3"
    _012V = "_012v"
    _4XM = "_4xm"
    _8BPS = "_8bps"
    A64_MULTI = "a64_multi"
    A64_MULTI5 = "a64_multi5"
    AASC = "aasc"
    AIC = "aic"
    ALIAS_PIX = "alias_pix"
    AMV = "amv"
    ANM = "anm"
    ANSI = "ansi"
    APNG = "apng"
    ASV1 = "asv1"
    ASV2 = "asv2"
    AURA = "aura"
    AURA2 = "aura2"
    AV1 = "av1"
    AVRN = "avrn"
    AVRP = "avrp"
    AVS = "avs"
    AVUI = "avui"
    AYUV = "ayuv"
    BETHSOFTVID = "bethsoftvid"
    BFI = "bfi"
    BINKVIDEO = "binkvideo"
    BINTEXT = "bintext"
    BITPACKED = "bitpacked"
    BMP = "bmp"
    BMV_VIDEO = "bmv_video"
    BRENDER_PIX = "brender_pix"
    C93 = "c93"
    CAVS = "cavs"
    CDGRAPHICS = "cdgraphics"
    CDXL = "cdxl"
    CFHD = "cfhd"
    CINEPAK = "cinepak"
    CLEARVIDEO = "clearvideo"
    CLJR = "cljr"
    CLLC = "cllc"
    CMV = "cmv"
    CPIA = "cpia"
    CSCD = "cscd"
    CYUV = "cyuv"
    DAALA = "daala"
    DDS = "dds"
    DFA = "dfa"
    DIRAC = "dirac"
    DNXHD = "dnxhd"
    DPX = "dpx"
    DSICINVIDEO = "dsicinvideo"
    DVVIDEO = "dvvideo"
    DXA = "dxa"
    DXTORY = "dxtory"
    DXV = "dxv"
    ESCAPE124 = "escape124"
    ESCAPE130 = "escape130"
    EXR = "exr"
    FFV1 = "ffv1"
    FFVHUFF = "ffvhuff"
    FIC = "fic"
    FITS = "fits"
    FLASHSV = "flashsv"
    FLASHSV2 = "flashsv2"
    FLIC = "flic"
    FMVC = "fmvc"
    FRAPS = "fraps"
    FRWU = "frwu"
    G2M = "g2m"
    GDV = "gdv"
    GIF = "gif"
    H261 = "h261"
    H263I = "h263i"
    HAP = "hap"
    HNM4VIDEO = "hnm4video"
    HQ_HQA = "hq_hqa"
    HQX = "hqx"
    HUFFYUV = "huffyuv"
    IDCIN = "idcin"
    IDF = "idf"
    IFF_ILBM = "iff_ilbm"
    INDEO2 = "indeo2"
    INDEO3 = "indeo3"
    INDEO4 = "indeo4"
    INDEO5 = "indeo5"
    INTERPLAYVIDEO = "interplayvideo"
    JPEG2000 = "jpeg2000"
    JPEGLS = "jpegls"
    JV = "jv"
    KGV1 = "kgv1"
    KMVC = "kmvc"
    LAGARITH = "lagarith"
    LJPEG = "ljpeg"
    LOCO = "loco"
    M101 = "m101"
    MAD = "mad"
    MAGICYUV = "magicyuv"
    MDEC = "mdec"
    MIMIC = "mimic"
    MJPEGB = "mjpegb"
    MMVIDEO = "mmvideo"
    MOTIONPIXELS = "motionpixels"
    MSA1 = "msa1"
    MSCC = "mscc"
    MSMPEG4V1 = "msmpeg4v1"
    MSMPEG4V2 = "msmpeg4v2"
    MSMPEG4V3 = "msmpeg4v3"
    MSRLE = "msrle"
    MSS1 = "mss1"
    MSS2 = "mss2"
    MSZH = "mszh"
    MTS2 = "mts2"
    MVC1 = "mvc1"
    MVC2 = "mvc2"
    MXPEG = "mxpeg"
    NUV = "nuv"
    PAF_VIDEO = "paf_video"
    PAM = "pam"
    PBM = "pbm"
    PCX = "pcx"
    PGM = "pgm"
    PGMYUV = "pgmyuv"
    PICTOR = "pictor"
    PIXLET = "pixlet"
    PNG = "png"
    PPM = "ppm"
    PRORES = "prores"
    PSD = "psd"
    PTX = "ptx"
    QDRAW = "qdraw"
    QPEG = "qpeg"
    QTRLE = "qtrle"
    R10K = "r10k"
    R210 = "r210"
    RAWVIDEO = "rawvideo"
    RL2 = "rl2"
    ROQ = "roq"
    RPZA = "rpza"
    RSCC = "rscc"
    RV10 = "rv10"
    RV20 = "rv20"
    RV30 = "rv30"
    RV40 = "rv40"
    SANM = "sanm"
    SCPR = "scpr"
    SCREENPRESSO = "screenpresso"
    SGI = "sgi"
    SGIRLE = "sgirle"
    SHEERVIDEO = "sheervideo"
    SMACKVIDEO = "smackvideo"
    SMC = "smc"
    SMVJPEG = "smvjpeg"
    SNOW = "snow"
    SP5X = "sp5x"
    SPEEDHQ = "speedhq"
    SRGC = "srgc"
    SUNRAST = "sunrast"
    SVG = "svg"
    SVQ1 = "svq1"
    SVQ3 = "svq3"
    TARGA = "targa"
    TARGA_Y216 = "targa_y216"
    TDSC = "tdsc"
    TGQ = "tgq"
    TGV = "tgv"
    THP = "thp"
    TIERTEXSEQVIDEO = "tiertexseqvideo"
    TIFF = "tiff"
    TMV = "tmv"
    TQI = "tqi"
    TRUEMOTION1 = "truemotion1"
    TRUEMOTION2 = "truemotion2"
    TRUEMOTION2RT = "truemotion2rt"
    TSCC = "tscc"
    TSCC2 = "tscc2"
    TXD = "txd"
    ULTI = "ulti"
    UTVIDEO = "utvideo"
    V210 = "v210"
    V210X = "v210x"
    V308 = "v308"
    V408 = "v408"
    V410 = "v410"
    VB = "vb"
    VBLE = "vble"
    VCR1 = "vcr1"
    VIXL = "vixl"
    VMDVIDEO = "vmdvideo"
    VMNC = "vmnc"
    VP3 = "vp3"
    VP5 = "vp5"
    VP6 = "vp6"
    VP6A = "vp6a"
    VP6F = "vp6f"
    VP7 = "vp7"
    WEBP = "webp"
    WMV3IMAGE = "wmv3image"
    WNV1 = "wnv1"
    WRAPPED_AVFRAME = "wrapped_avframe"
    WS_VQA = "ws_vqa"
    XAN_WC3 = "xan_wc3"
    XAN_WC4 = "xan_wc4"
    XBIN = "xbin"
    XBM = "xbm"
    XFACE = "xface"
    XPM = "xpm"
    XWD = "xwd"
    Y41P = "y41p"
    YLC = "ylc"
    YOP = "yop"
    YUV4 = "yuv4"
    ZEROCODEC = "zerocodec"
    ZLIB = "zlib"
    ZMBV = "zmbv"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """VideoMediaTypes - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VideoMediaTypes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoMediaTypes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class ChannelServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_channels(self, **kwargs):  # noqa: E501
        """Gets available channels  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_channels(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param int limit: Optional. The maximum number of records to return
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_channels_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_channels_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_channels_with_http_info(self, **kwargs):  # noqa: E501
        """Gets available channels  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_channels_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param int limit: Optional. The maximum number of records to return
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'start_index', 'fields', 'limit', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_channels" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Channels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class CommonPluginsIPlugin(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'id': 'str',
        'version': 'Version',
        'assembly_file_path': 'str',
        'data_folder_path': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'description': 'Description',
        'id': 'Id',
        'version': 'Version',
        'assembly_file_path': 'AssemblyFilePath',
        'data_folder_path': 'DataFolderPath'
    }

    def __init__(self, name=None, description=None, id=None, version=None, assembly_file_path=None, data_folder_path=None):  # noqa: E501
        """CommonPluginsIPlugin - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._id = None
        self._version = None
        self._assembly_file_path = None
        self._data_folder_path = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if version is not None:
            self.version = version
        if assembly_file_path is not None:
            self.assembly_file_path = assembly_file_path
        if data_folder_path is not None:
            self.data_folder_path = data_folder_path

    @property
    def name(self):
        """Gets the name of this CommonPluginsIPlugin.  # noqa: E501

        The name of the plugin  # noqa: E501

        :return: The name of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommonPluginsIPlugin.

        The name of the plugin  # noqa: E501

        :param name: The name of this CommonPluginsIPlugin.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this CommonPluginsIPlugin.  # noqa: E501

        The description.  # noqa: E501

        :return: The description of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CommonPluginsIPlugin.

        The description.  # noqa: E501

        :param description: The description of this CommonPluginsIPlugin.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this CommonPluginsIPlugin.  # noqa: E501

        The unique id.  # noqa: E501

        :return: The id of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CommonPluginsIPlugin.

        The unique id.  # noqa: E501

        :param id: The id of this CommonPluginsIPlugin.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def version(self):
        """Gets the version of this CommonPluginsIPlugin.  # noqa: E501


        :return: The version of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: Version
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CommonPluginsIPlugin.


        :param version: The version of this CommonPluginsIPlugin.  # noqa: E501
        :type: Version
        """

        self._version = version

    @property
    def assembly_file_path(self):
        """Gets the assembly_file_path of this CommonPluginsIPlugin.  # noqa: E501

        The path to the assembly file  # noqa: E501

        :return: The assembly_file_path of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: str
        """
        return self._assembly_file_path

    @assembly_file_path.setter
    def assembly_file_path(self, assembly_file_path):
        """Sets the assembly_file_path of this CommonPluginsIPlugin.

        The path to the assembly file  # noqa: E501

        :param assembly_file_path: The assembly_file_path of this CommonPluginsIPlugin.  # noqa: E501
        :type: str
        """

        self._assembly_file_path = assembly_file_path

    @property
    def data_folder_path(self):
        """Gets the data_folder_path of this CommonPluginsIPlugin.  # noqa: E501

        The full path to the data folder, where the plugin can store any miscellaneous files needed  # noqa: E501

        :return: The data_folder_path of this CommonPluginsIPlugin.  # noqa: E501
        :rtype: str
        """
        return self._data_folder_path

    @data_folder_path.setter
    def data_folder_path(self, data_folder_path):
        """Sets the data_folder_path of this CommonPluginsIPlugin.

        The full path to the data folder, where the plugin can store any miscellaneous files needed  # noqa: E501

        :param data_folder_path: The data_folder_path of this CommonPluginsIPlugin.  # noqa: E501
        :type: str
        """

        self._data_folder_path = data_folder_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommonPluginsIPlugin, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonPluginsIPlugin):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ServerConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable_upn_p': 'bool',
        'public_port': 'int',
        'public_https_port': 'int',
        'http_server_port_number': 'int',
        'https_port_number': 'int',
        'enable_https': 'bool',
        'certificate_path': 'str',
        'certificate_password': 'str',
        'is_port_authorized': 'bool',
        'auto_run_web_app': 'bool',
        'enable_remote_access': 'bool',
        'log_all_query_times': 'bool',
        'enable_case_sensitive_item_ids': 'bool',
        'metadata_path': 'str',
        'metadata_network_path': 'str',
        'preferred_metadata_language': 'str',
        'metadata_country_code': 'str',
        'sort_remove_words': 'list[str]',
        'library_monitor_delay_seconds': 'int',
        'enable_dashboard_response_caching': 'bool',
        'dashboard_source_path': 'str',
        'image_saving_convention': 'ImageSavingConvention',
        'enable_automatic_restart': 'bool',
        'server_name': 'str',
        'preferred_detected_remote_address_family': 'NetSocketsAddressFamily',
        'wan_ddns': 'str',
        'ui_culture': 'str',
        'remote_client_bitrate_limit': 'int',
        'local_network_subnets': 'list[str]',
        'local_network_addresses': 'list[str]',
        'enable_external_content_in_suggestions': 'bool',
        'require_https': 'bool',
        'is_behind_proxy': 'bool',
        'remote_ip_filter': 'list[str]',
        'is_remote_ip_filter_blacklist': 'bool',
        'image_extraction_timeout_ms': 'int',
        'path_substitutions': 'list[PathSubstitution]',
        'uninstalled_plugins': 'list[str]',
        'collapse_video_folders': 'bool',
        'enable_original_track_titles': 'bool',
        'vacuum_database_on_startup': 'bool',
        'simultaneous_stream_limit': 'int',
        'database_cache_size_mb': 'int',
        'enable_sq_lite_mmio': 'bool',
        'playlists_upgraded_to_m3_u': 'bool',
        'image_extractor_upgraded1': 'bool',
        'enable_people_letter_sub_folders': 'bool',
        'optimize_database_on_shutdown': 'bool',
        'database_analysis_limit': 'int',
        'disable_async_io': 'bool',
        'migrated_to_user_item_shares8': 'bool',
        'migrated_library_options_to_db': 'bool',
        'allow_legacy_local_network_password': 'bool',
        'enable_saved_metadata_for_people': 'bool',
        'tv_channels_refreshed': 'bool',
        'proxy_header_mode': 'ProxyHeaderMode',
        'enable_debug_level_logging': 'bool',
        'revert_debug_logging': 'str',
        'enable_auto_update': 'bool',
        'log_file_retention_days': 'int',
        'run_at_startup': 'bool',
        'is_startup_wizard_completed': 'bool',
        'cache_path': 'str'
    }

    attribute_map = {
        'enable_upn_p': 'EnableUPnP',
        'public_port': 'PublicPort',
        'public_https_port': 'PublicHttpsPort',
        'http_server_port_number': 'HttpServerPortNumber',
        'https_port_number': 'HttpsPortNumber',
        'enable_https': 'EnableHttps',
        'certificate_path': 'CertificatePath',
        'certificate_password': 'CertificatePassword',
        'is_port_authorized': 'IsPortAuthorized',
        'auto_run_web_app': 'AutoRunWebApp',
        'enable_remote_access': 'EnableRemoteAccess',
        'log_all_query_times': 'LogAllQueryTimes',
        'enable_case_sensitive_item_ids': 'EnableCaseSensitiveItemIds',
        'metadata_path': 'MetadataPath',
        'metadata_network_path': 'MetadataNetworkPath',
        'preferred_metadata_language': 'PreferredMetadataLanguage',
        'metadata_country_code': 'MetadataCountryCode',
        'sort_remove_words': 'SortRemoveWords',
        'library_monitor_delay_seconds': 'LibraryMonitorDelaySeconds',
        'enable_dashboard_response_caching': 'EnableDashboardResponseCaching',
        'dashboard_source_path': 'DashboardSourcePath',
        'image_saving_convention': 'ImageSavingConvention',
        'enable_automatic_restart': 'EnableAutomaticRestart',
        'server_name': 'ServerName',
        'preferred_detected_remote_address_family': 'PreferredDetectedRemoteAddressFamily',
        'wan_ddns': 'WanDdns',
        'ui_culture': 'UICulture',
        'remote_client_bitrate_limit': 'RemoteClientBitrateLimit',
        'local_network_subnets': 'LocalNetworkSubnets',
        'local_network_addresses': 'LocalNetworkAddresses',
        'enable_external_content_in_suggestions': 'EnableExternalContentInSuggestions',
        'require_https': 'RequireHttps',
        'is_behind_proxy': 'IsBehindProxy',
        'remote_ip_filter': 'RemoteIPFilter',
        'is_remote_ip_filter_blacklist': 'IsRemoteIPFilterBlacklist',
        'image_extraction_timeout_ms': 'ImageExtractionTimeoutMs',
        'path_substitutions': 'PathSubstitutions',
        'uninstalled_plugins': 'UninstalledPlugins',
        'collapse_video_folders': 'CollapseVideoFolders',
        'enable_original_track_titles': 'EnableOriginalTrackTitles',
        'vacuum_database_on_startup': 'VacuumDatabaseOnStartup',
        'simultaneous_stream_limit': 'SimultaneousStreamLimit',
        'database_cache_size_mb': 'DatabaseCacheSizeMB',
        'enable_sq_lite_mmio': 'EnableSqLiteMmio',
        'playlists_upgraded_to_m3_u': 'PlaylistsUpgradedToM3U',
        'image_extractor_upgraded1': 'ImageExtractorUpgraded1',
        'enable_people_letter_sub_folders': 'EnablePeopleLetterSubFolders',
        'optimize_database_on_shutdown': 'OptimizeDatabaseOnShutdown',
        'database_analysis_limit': 'DatabaseAnalysisLimit',
        'disable_async_io': 'DisableAsyncIO',
        'migrated_to_user_item_shares8': 'MigratedToUserItemShares8',
        'migrated_library_options_to_db': 'MigratedLibraryOptionsToDb',
        'allow_legacy_local_network_password': 'AllowLegacyLocalNetworkPassword',
        'enable_saved_metadata_for_people': 'EnableSavedMetadataForPeople',
        'tv_channels_refreshed': 'TvChannelsRefreshed',
        'proxy_header_mode': 'ProxyHeaderMode',
        'enable_debug_level_logging': 'EnableDebugLevelLogging',
        'revert_debug_logging': 'RevertDebugLogging',
        'enable_auto_update': 'EnableAutoUpdate',
        'log_file_retention_days': 'LogFileRetentionDays',
        'run_at_startup': 'RunAtStartup',
        'is_startup_wizard_completed': 'IsStartupWizardCompleted',
        'cache_path': 'CachePath'
    }

    def __init__(self, enable_upn_p=None, public_port=None, public_https_port=None, http_server_port_number=None, https_port_number=None, enable_https=None, certificate_path=None, certificate_password=None, is_port_authorized=None, auto_run_web_app=None, enable_remote_access=None, log_all_query_times=None, enable_case_sensitive_item_ids=None, metadata_path=None, metadata_network_path=None, preferred_metadata_language=None, metadata_country_code=None, sort_remove_words=None, library_monitor_delay_seconds=None, enable_dashboard_response_caching=None, dashboard_source_path=None, image_saving_convention=None, enable_automatic_restart=None, server_name=None, preferred_detected_remote_address_family=None, wan_ddns=None, ui_culture=None, remote_client_bitrate_limit=None, local_network_subnets=None, local_network_addresses=None, enable_external_content_in_suggestions=None, require_https=None, is_behind_proxy=None, remote_ip_filter=None, is_remote_ip_filter_blacklist=None, image_extraction_timeout_ms=None, path_substitutions=None, uninstalled_plugins=None, collapse_video_folders=None, enable_original_track_titles=None, vacuum_database_on_startup=None, simultaneous_stream_limit=None, database_cache_size_mb=None, enable_sq_lite_mmio=None, playlists_upgraded_to_m3_u=None, image_extractor_upgraded1=None, enable_people_letter_sub_folders=None, optimize_database_on_shutdown=None, database_analysis_limit=None, disable_async_io=None, migrated_to_user_item_shares8=None, migrated_library_options_to_db=None, allow_legacy_local_network_password=None, enable_saved_metadata_for_people=None, tv_channels_refreshed=None, proxy_header_mode=None, enable_debug_level_logging=None, revert_debug_logging=None, enable_auto_update=None, log_file_retention_days=None, run_at_startup=None, is_startup_wizard_completed=None, cache_path=None):  # noqa: E501
        """ServerConfiguration - a model defined in Swagger"""  # noqa: E501
        self._enable_upn_p = None
        self._public_port = None
        self._public_https_port = None
        self._http_server_port_number = None
        self._https_port_number = None
        self._enable_https = None
        self._certificate_path = None
        self._certificate_password = None
        self._is_port_authorized = None
        self._auto_run_web_app = None
        self._enable_remote_access = None
        self._log_all_query_times = None
        self._enable_case_sensitive_item_ids = None
        self._metadata_path = None
        self._metadata_network_path = None
        self._preferred_metadata_language = None
        self._metadata_country_code = None
        self._sort_remove_words = None
        self._library_monitor_delay_seconds = None
        self._enable_dashboard_response_caching = None
        self._dashboard_source_path = None
        self._image_saving_convention = None
        self._enable_automatic_restart = None
        self._server_name = None
        self._preferred_detected_remote_address_family = None
        self._wan_ddns = None
        self._ui_culture = None
        self._remote_client_bitrate_limit = None
        self._local_network_subnets = None
        self._local_network_addresses = None
        self._enable_external_content_in_suggestions = None
        self._require_https = None
        self._is_behind_proxy = None
        self._remote_ip_filter = None
        self._is_remote_ip_filter_blacklist = None
        self._image_extraction_timeout_ms = None
        self._path_substitutions = None
        self._uninstalled_plugins = None
        self._collapse_video_folders = None
        self._enable_original_track_titles = None
        self._vacuum_database_on_startup = None
        self._simultaneous_stream_limit = None
        self._database_cache_size_mb = None
        self._enable_sq_lite_mmio = None
        self._playlists_upgraded_to_m3_u = None
        self._image_extractor_upgraded1 = None
        self._enable_people_letter_sub_folders = None
        self._optimize_database_on_shutdown = None
        self._database_analysis_limit = None
        self._disable_async_io = None
        self._migrated_to_user_item_shares8 = None
        self._migrated_library_options_to_db = None
        self._allow_legacy_local_network_password = None
        self._enable_saved_metadata_for_people = None
        self._tv_channels_refreshed = None
        self._proxy_header_mode = None
        self._enable_debug_level_logging = None
        self._revert_debug_logging = None
        self._enable_auto_update = None
        self._log_file_retention_days = None
        self._run_at_startup = None
        self._is_startup_wizard_completed = None
        self._cache_path = None
        self.discriminator = None
        if enable_upn_p is not None:
            self.enable_upn_p = enable_upn_p
        if public_port is not None:
            self.public_port = public_port
        if public_https_port is not None:
            self.public_https_port = public_https_port
        if http_server_port_number is not None:
            self.http_server_port_number = http_server_port_number
        if https_port_number is not None:
            self.https_port_number = https_port_number
        if enable_https is not None:
            self.enable_https = enable_https
        if certificate_path is not None:
            self.certificate_path = certificate_path
        if certificate_password is not None:
            self.certificate_password = certificate_password
        if is_port_authorized is not None:
            self.is_port_authorized = is_port_authorized
        if auto_run_web_app is not None:
            self.auto_run_web_app = auto_run_web_app
        if enable_remote_access is not None:
            self.enable_remote_access = enable_remote_access
        if log_all_query_times is not None:
            self.log_all_query_times = log_all_query_times
        if enable_case_sensitive_item_ids is not None:
            self.enable_case_sensitive_item_ids = enable_case_sensitive_item_ids
        if metadata_path is not None:
            self.metadata_path = metadata_path
        if metadata_network_path is not None:
            self.metadata_network_path = metadata_network_path
        if preferred_metadata_language is not None:
            self.preferred_metadata_language = preferred_metadata_language
        if metadata_country_code is not None:
            self.metadata_country_code = metadata_country_code
        if sort_remove_words is not None:
            self.sort_remove_words = sort_remove_words
        if library_monitor_delay_seconds is not None:
            self.library_monitor_delay_seconds = library_monitor_delay_seconds
        if enable_dashboard_response_caching is not None:
            self.enable_dashboard_response_caching = enable_dashboard_response_caching
        if dashboard_source_path is not None:
            self.dashboard_source_path = dashboard_source_path
        if image_saving_convention is not None:
            self.image_saving_convention = image_saving_convention
        if enable_automatic_restart is not None:
            self.enable_automatic_restart = enable_automatic_restart
        if server_name is not None:
            self.server_name = server_name
        if preferred_detected_remote_address_family is not None:
            self.preferred_detected_remote_address_family = preferred_detected_remote_address_family
        if wan_ddns is not None:
            self.wan_ddns = wan_ddns
        if ui_culture is not None:
            self.ui_culture = ui_culture
        if remote_client_bitrate_limit is not None:
            self.remote_client_bitrate_limit = remote_client_bitrate_limit
        if local_network_subnets is not None:
            self.local_network_subnets = local_network_subnets
        if local_network_addresses is not None:
            self.local_network_addresses = local_network_addresses
        if enable_external_content_in_suggestions is not None:
            self.enable_external_content_in_suggestions = enable_external_content_in_suggestions
        if require_https is not None:
            self.require_https = require_https
        if is_behind_proxy is not None:
            self.is_behind_proxy = is_behind_proxy
        if remote_ip_filter is not None:
            self.remote_ip_filter = remote_ip_filter
        if is_remote_ip_filter_blacklist is not None:
            self.is_remote_ip_filter_blacklist = is_remote_ip_filter_blacklist
        if image_extraction_timeout_ms is not None:
            self.image_extraction_timeout_ms = image_extraction_timeout_ms
        if path_substitutions is not None:
            self.path_substitutions = path_substitutions
        if uninstalled_plugins is not None:
            self.uninstalled_plugins = uninstalled_plugins
        if collapse_video_folders is not None:
            self.collapse_video_folders = collapse_video_folders
        if enable_original_track_titles is not None:
            self.enable_original_track_titles = enable_original_track_titles
        if vacuum_database_on_startup is not None:
            self.vacuum_database_on_startup = vacuum_database_on_startup
        if simultaneous_stream_limit is not None:
            self.simultaneous_stream_limit = simultaneous_stream_limit
        if database_cache_size_mb is not None:
            self.database_cache_size_mb = database_cache_size_mb
        if enable_sq_lite_mmio is not None:
            self.enable_sq_lite_mmio = enable_sq_lite_mmio
        if playlists_upgraded_to_m3_u is not None:
            self.playlists_upgraded_to_m3_u = playlists_upgraded_to_m3_u
        if image_extractor_upgraded1 is not None:
            self.image_extractor_upgraded1 = image_extractor_upgraded1
        if enable_people_letter_sub_folders is not None:
            self.enable_people_letter_sub_folders = enable_people_letter_sub_folders
        if optimize_database_on_shutdown is not None:
            self.optimize_database_on_shutdown = optimize_database_on_shutdown
        if database_analysis_limit is not None:
            self.database_analysis_limit = database_analysis_limit
        if disable_async_io is not None:
            self.disable_async_io = disable_async_io
        if migrated_to_user_item_shares8 is not None:
            self.migrated_to_user_item_shares8 = migrated_to_user_item_shares8
        if migrated_library_options_to_db is not None:
            self.migrated_library_options_to_db = migrated_library_options_to_db
        if allow_legacy_local_network_password is not None:
            self.allow_legacy_local_network_password = allow_legacy_local_network_password
        if enable_saved_metadata_for_people is not None:
            self.enable_saved_metadata_for_people = enable_saved_metadata_for_people
        if tv_channels_refreshed is not None:
            self.tv_channels_refreshed = tv_channels_refreshed
        if proxy_header_mode is not None:
            self.proxy_header_mode = proxy_header_mode
        if enable_debug_level_logging is not None:
            self.enable_debug_level_logging = enable_debug_level_logging
        if revert_debug_logging is not None:
            self.revert_debug_logging = revert_debug_logging
        if enable_auto_update is not None:
            self.enable_auto_update = enable_auto_update
        if log_file_retention_days is not None:
            self.log_file_retention_days = log_file_retention_days
        if run_at_startup is not None:
            self.run_at_startup = run_at_startup
        if is_startup_wizard_completed is not None:
            self.is_startup_wizard_completed = is_startup_wizard_completed
        if cache_path is not None:
            self.cache_path = cache_path

    @property
    def enable_upn_p(self):
        """Gets the enable_upn_p of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[enable u pn p\\].  # noqa: E501

        :return: The enable_upn_p of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_upn_p

    @enable_upn_p.setter
    def enable_upn_p(self, enable_upn_p):
        """Sets the enable_upn_p of this ServerConfiguration.

        A value indicating whether \\[enable u pn p\\].  # noqa: E501

        :param enable_upn_p: The enable_upn_p of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_upn_p = enable_upn_p

    @property
    def public_port(self):
        """Gets the public_port of this ServerConfiguration.  # noqa: E501

        The public mapped port.  # noqa: E501

        :return: The public_port of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._public_port

    @public_port.setter
    def public_port(self, public_port):
        """Sets the public_port of this ServerConfiguration.

        The public mapped port.  # noqa: E501

        :param public_port: The public_port of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._public_port = public_port

    @property
    def public_https_port(self):
        """Gets the public_https_port of this ServerConfiguration.  # noqa: E501

        The public HTTPS port.  # noqa: E501

        :return: The public_https_port of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._public_https_port

    @public_https_port.setter
    def public_https_port(self, public_https_port):
        """Sets the public_https_port of this ServerConfiguration.

        The public HTTPS port.  # noqa: E501

        :param public_https_port: The public_https_port of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._public_https_port = public_https_port

    @property
    def http_server_port_number(self):
        """Gets the http_server_port_number of this ServerConfiguration.  # noqa: E501

        The HTTP server port number.  # noqa: E501

        :return: The http_server_port_number of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._http_server_port_number

    @http_server_port_number.setter
    def http_server_port_number(self, http_server_port_number):
        """Sets the http_server_port_number of this ServerConfiguration.

        The HTTP server port number.  # noqa: E501

        :param http_server_port_number: The http_server_port_number of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._http_server_port_number = http_server_port_number

    @property
    def https_port_number(self):
        """Gets the https_port_number of this ServerConfiguration.  # noqa: E501

        The HTTPS server port number.  # noqa: E501

        :return: The https_port_number of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._https_port_number

    @https_port_number.setter
    def https_port_number(self, https_port_number):
        """Sets the https_port_number of this ServerConfiguration.

        The HTTPS server port number.  # noqa: E501

        :param https_port_number: The https_port_number of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._https_port_number = https_port_number

    @property
    def enable_https(self):
        """Gets the enable_https of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[use HTTPS\\].  # noqa: E501

        :return: The enable_https of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_https

    @enable_https.setter
    def enable_https(self, enable_https):
        """Sets the enable_https of this ServerConfiguration.

        A value indicating whether \\[use HTTPS\\].  # noqa: E501

        :param enable_https: The enable_https of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_https = enable_https

    @property
    def certificate_path(self):
        """Gets the certificate_path of this ServerConfiguration.  # noqa: E501

        The value pointing to the file system where the ssl certiifcate is located..  # noqa: E501

        :return: The certificate_path of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._certificate_path

    @certificate_path.setter
    def certificate_path(self, certificate_path):
        """Sets the certificate_path of this ServerConfiguration.

        The value pointing to the file system where the ssl certiifcate is located..  # noqa: E501

        :param certificate_path: The certificate_path of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._certificate_path = certificate_path

    @property
    def certificate_password(self):
        """Gets the certificate_password of this ServerConfiguration.  # noqa: E501


        :return: The certificate_password of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._certificate_password

    @certificate_password.setter
    def certificate_password(self, certificate_password):
        """Sets the certificate_password of this ServerConfiguration.


        :param certificate_password: The certificate_password of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._certificate_password = certificate_password

    @property
    def is_port_authorized(self):
        """Gets the is_port_authorized of this ServerConfiguration.  # noqa: E501

        A value indicating whether this instance is port authorized.  # noqa: E501

        :return: The is_port_authorized of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_port_authorized

    @is_port_authorized.setter
    def is_port_authorized(self, is_port_authorized):
        """Sets the is_port_authorized of this ServerConfiguration.

        A value indicating whether this instance is port authorized.  # noqa: E501

        :param is_port_authorized: The is_port_authorized of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_port_authorized = is_port_authorized

    @property
    def auto_run_web_app(self):
        """Gets the auto_run_web_app of this ServerConfiguration.  # noqa: E501


        :return: The auto_run_web_app of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._auto_run_web_app

    @auto_run_web_app.setter
    def auto_run_web_app(self, auto_run_web_app):
        """Sets the auto_run_web_app of this ServerConfiguration.


        :param auto_run_web_app: The auto_run_web_app of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._auto_run_web_app = auto_run_web_app

    @property
    def enable_remote_access(self):
        """Gets the enable_remote_access of this ServerConfiguration.  # noqa: E501


        :return: The enable_remote_access of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_remote_access

    @enable_remote_access.setter
    def enable_remote_access(self, enable_remote_access):
        """Sets the enable_remote_access of this ServerConfiguration.


        :param enable_remote_access: The enable_remote_access of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_remote_access = enable_remote_access

    @property
    def log_all_query_times(self):
        """Gets the log_all_query_times of this ServerConfiguration.  # noqa: E501


        :return: The log_all_query_times of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._log_all_query_times

    @log_all_query_times.setter
    def log_all_query_times(self, log_all_query_times):
        """Sets the log_all_query_times of this ServerConfiguration.


        :param log_all_query_times: The log_all_query_times of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._log_all_query_times = log_all_query_times

    @property
    def enable_case_sensitive_item_ids(self):
        """Gets the enable_case_sensitive_item_ids of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[enable case sensitive item ids\\].  # noqa: E501

        :return: The enable_case_sensitive_item_ids of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_case_sensitive_item_ids

    @enable_case_sensitive_item_ids.setter
    def enable_case_sensitive_item_ids(self, enable_case_sensitive_item_ids):
        """Sets the enable_case_sensitive_item_ids of this ServerConfiguration.

        A value indicating whether \\[enable case sensitive item ids\\].  # noqa: E501

        :param enable_case_sensitive_item_ids: The enable_case_sensitive_item_ids of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_case_sensitive_item_ids = enable_case_sensitive_item_ids

    @property
    def metadata_path(self):
        """Gets the metadata_path of this ServerConfiguration.  # noqa: E501

        The metadata path.  # noqa: E501

        :return: The metadata_path of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._metadata_path

    @metadata_path.setter
    def metadata_path(self, metadata_path):
        """Sets the metadata_path of this ServerConfiguration.

        The metadata path.  # noqa: E501

        :param metadata_path: The metadata_path of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._metadata_path = metadata_path

    @property
    def metadata_network_path(self):
        """Gets the metadata_network_path of this ServerConfiguration.  # noqa: E501


        :return: The metadata_network_path of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._metadata_network_path

    @metadata_network_path.setter
    def metadata_network_path(self, metadata_network_path):
        """Sets the metadata_network_path of this ServerConfiguration.


        :param metadata_network_path: The metadata_network_path of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._metadata_network_path = metadata_network_path

    @property
    def preferred_metadata_language(self):
        """Gets the preferred_metadata_language of this ServerConfiguration.  # noqa: E501

        The preferred metadata language.  # noqa: E501

        :return: The preferred_metadata_language of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._preferred_metadata_language

    @preferred_metadata_language.setter
    def preferred_metadata_language(self, preferred_metadata_language):
        """Sets the preferred_metadata_language of this ServerConfiguration.

        The preferred metadata language.  # noqa: E501

        :param preferred_metadata_language: The preferred_metadata_language of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._preferred_metadata_language = preferred_metadata_language

    @property
    def metadata_country_code(self):
        """Gets the metadata_country_code of this ServerConfiguration.  # noqa: E501

        The metadata country code.  # noqa: E501

        :return: The metadata_country_code of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._metadata_country_code

    @metadata_country_code.setter
    def metadata_country_code(self, metadata_country_code):
        """Sets the metadata_country_code of this ServerConfiguration.

        The metadata country code.  # noqa: E501

        :param metadata_country_code: The metadata_country_code of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._metadata_country_code = metadata_country_code

    @property
    def sort_remove_words(self):
        """Gets the sort_remove_words of this ServerConfiguration.  # noqa: E501

        Words to be removed from strings to create a sort name  # noqa: E501

        :return: The sort_remove_words of this ServerConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_remove_words

    @sort_remove_words.setter
    def sort_remove_words(self, sort_remove_words):
        """Sets the sort_remove_words of this ServerConfiguration.

        Words to be removed from strings to create a sort name  # noqa: E501

        :param sort_remove_words: The sort_remove_words of this ServerConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._sort_remove_words = sort_remove_words

    @property
    def library_monitor_delay_seconds(self):
        """Gets the library_monitor_delay_seconds of this ServerConfiguration.  # noqa: E501

        The delay in seconds that we will wait after a file system change to try and discover what has been added/removed Some delay is necessary with some items because their creation is not atomic.  It involves the creation of several different directories and files.  # noqa: E501

        :return: The library_monitor_delay_seconds of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._library_monitor_delay_seconds

    @library_monitor_delay_seconds.setter
    def library_monitor_delay_seconds(self, library_monitor_delay_seconds):
        """Sets the library_monitor_delay_seconds of this ServerConfiguration.

        The delay in seconds that we will wait after a file system change to try and discover what has been added/removed Some delay is necessary with some items because their creation is not atomic.  It involves the creation of several different directories and files.  # noqa: E501

        :param library_monitor_delay_seconds: The library_monitor_delay_seconds of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._library_monitor_delay_seconds = library_monitor_delay_seconds

    @property
    def enable_dashboard_response_caching(self):
        """Gets the enable_dashboard_response_caching of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[enable dashboard response caching\\]. Allows potential contributors without visual studio to modify production dashboard code and test changes.  # noqa: E501

        :return: The enable_dashboard_response_caching of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_dashboard_response_caching

    @enable_dashboard_response_caching.setter
    def enable_dashboard_response_caching(self, enable_dashboard_response_caching):
        """Sets the enable_dashboard_response_caching of this ServerConfiguration.

        A value indicating whether \\[enable dashboard response caching\\]. Allows potential contributors without visual studio to modify production dashboard code and test changes.  # noqa: E501

        :param enable_dashboard_response_caching: The enable_dashboard_response_caching of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_dashboard_response_caching = enable_dashboard_response_caching

    @property
    def dashboard_source_path(self):
        """Gets the dashboard_source_path of this ServerConfiguration.  # noqa: E501

        Allows the dashboard to be served from a custom path.  # noqa: E501

        :return: The dashboard_source_path of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_source_path

    @dashboard_source_path.setter
    def dashboard_source_path(self, dashboard_source_path):
        """Sets the dashboard_source_path of this ServerConfiguration.

        Allows the dashboard to be served from a custom path.  # noqa: E501

        :param dashboard_source_path: The dashboard_source_path of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._dashboard_source_path = dashboard_source_path

    @property
    def image_saving_convention(self):
        """Gets the image_saving_convention of this ServerConfiguration.  # noqa: E501


        :return: The image_saving_convention of this ServerConfiguration.  # noqa: E501
        :rtype: ImageSavingConvention
        """
        return self._image_saving_convention

    @image_saving_convention.setter
    def image_saving_convention(self, image_saving_convention):
        """Sets the image_saving_convention of this ServerConfiguration.


        :param image_saving_convention: The image_saving_convention of this ServerConfiguration.  # noqa: E501
        :type: ImageSavingConvention
        """

        self._image_saving_convention = image_saving_convention

    @property
    def enable_automatic_restart(self):
        """Gets the enable_automatic_restart of this ServerConfiguration.  # noqa: E501


        :return: The enable_automatic_restart of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_automatic_restart

    @enable_automatic_restart.setter
    def enable_automatic_restart(self, enable_automatic_restart):
        """Sets the enable_automatic_restart of this ServerConfiguration.


        :param enable_automatic_restart: The enable_automatic_restart of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_automatic_restart = enable_automatic_restart

    @property
    def server_name(self):
        """Gets the server_name of this ServerConfiguration.  # noqa: E501


        :return: The server_name of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this ServerConfiguration.


        :param server_name: The server_name of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def preferred_detected_remote_address_family(self):
        """Gets the preferred_detected_remote_address_family of this ServerConfiguration.  # noqa: E501


        :return: The preferred_detected_remote_address_family of this ServerConfiguration.  # noqa: E501
        :rtype: NetSocketsAddressFamily
        """
        return self._preferred_detected_remote_address_family

    @preferred_detected_remote_address_family.setter
    def preferred_detected_remote_address_family(self, preferred_detected_remote_address_family):
        """Sets the preferred_detected_remote_address_family of this ServerConfiguration.


        :param preferred_detected_remote_address_family: The preferred_detected_remote_address_family of this ServerConfiguration.  # noqa: E501
        :type: NetSocketsAddressFamily
        """

        self._preferred_detected_remote_address_family = preferred_detected_remote_address_family

    @property
    def wan_ddns(self):
        """Gets the wan_ddns of this ServerConfiguration.  # noqa: E501


        :return: The wan_ddns of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._wan_ddns

    @wan_ddns.setter
    def wan_ddns(self, wan_ddns):
        """Sets the wan_ddns of this ServerConfiguration.


        :param wan_ddns: The wan_ddns of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._wan_ddns = wan_ddns

    @property
    def ui_culture(self):
        """Gets the ui_culture of this ServerConfiguration.  # noqa: E501


        :return: The ui_culture of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._ui_culture

    @ui_culture.setter
    def ui_culture(self, ui_culture):
        """Sets the ui_culture of this ServerConfiguration.


        :param ui_culture: The ui_culture of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._ui_culture = ui_culture

    @property
    def remote_client_bitrate_limit(self):
        """Gets the remote_client_bitrate_limit of this ServerConfiguration.  # noqa: E501


        :return: The remote_client_bitrate_limit of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._remote_client_bitrate_limit

    @remote_client_bitrate_limit.setter
    def remote_client_bitrate_limit(self, remote_client_bitrate_limit):
        """Sets the remote_client_bitrate_limit of this ServerConfiguration.


        :param remote_client_bitrate_limit: The remote_client_bitrate_limit of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._remote_client_bitrate_limit = remote_client_bitrate_limit

    @property
    def local_network_subnets(self):
        """Gets the local_network_subnets of this ServerConfiguration.  # noqa: E501


        :return: The local_network_subnets of this ServerConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._local_network_subnets

    @local_network_subnets.setter
    def local_network_subnets(self, local_network_subnets):
        """Sets the local_network_subnets of this ServerConfiguration.


        :param local_network_subnets: The local_network_subnets of this ServerConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._local_network_subnets = local_network_subnets

    @property
    def local_network_addresses(self):
        """Gets the local_network_addresses of this ServerConfiguration.  # noqa: E501


        :return: The local_network_addresses of this ServerConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._local_network_addresses

    @local_network_addresses.setter
    def local_network_addresses(self, local_network_addresses):
        """Sets the local_network_addresses of this ServerConfiguration.


        :param local_network_addresses: The local_network_addresses of this ServerConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._local_network_addresses = local_network_addresses

    @property
    def enable_external_content_in_suggestions(self):
        """Gets the enable_external_content_in_suggestions of this ServerConfiguration.  # noqa: E501


        :return: The enable_external_content_in_suggestions of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_external_content_in_suggestions

    @enable_external_content_in_suggestions.setter
    def enable_external_content_in_suggestions(self, enable_external_content_in_suggestions):
        """Sets the enable_external_content_in_suggestions of this ServerConfiguration.


        :param enable_external_content_in_suggestions: The enable_external_content_in_suggestions of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_external_content_in_suggestions = enable_external_content_in_suggestions

    @property
    def require_https(self):
        """Gets the require_https of this ServerConfiguration.  # noqa: E501


        :return: The require_https of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._require_https

    @require_https.setter
    def require_https(self, require_https):
        """Sets the require_https of this ServerConfiguration.


        :param require_https: The require_https of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._require_https = require_https

    @property
    def is_behind_proxy(self):
        """Gets the is_behind_proxy of this ServerConfiguration.  # noqa: E501


        :return: The is_behind_proxy of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_behind_proxy

    @is_behind_proxy.setter
    def is_behind_proxy(self, is_behind_proxy):
        """Sets the is_behind_proxy of this ServerConfiguration.


        :param is_behind_proxy: The is_behind_proxy of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_behind_proxy = is_behind_proxy

    @property
    def remote_ip_filter(self):
        """Gets the remote_ip_filter of this ServerConfiguration.  # noqa: E501


        :return: The remote_ip_filter of this ServerConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._remote_ip_filter

    @remote_ip_filter.setter
    def remote_ip_filter(self, remote_ip_filter):
        """Sets the remote_ip_filter of this ServerConfiguration.


        :param remote_ip_filter: The remote_ip_filter of this ServerConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._remote_ip_filter = remote_ip_filter

    @property
    def is_remote_ip_filter_blacklist(self):
        """Gets the is_remote_ip_filter_blacklist of this ServerConfiguration.  # noqa: E501


        :return: The is_remote_ip_filter_blacklist of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_remote_ip_filter_blacklist

    @is_remote_ip_filter_blacklist.setter
    def is_remote_ip_filter_blacklist(self, is_remote_ip_filter_blacklist):
        """Sets the is_remote_ip_filter_blacklist of this ServerConfiguration.


        :param is_remote_ip_filter_blacklist: The is_remote_ip_filter_blacklist of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_remote_ip_filter_blacklist = is_remote_ip_filter_blacklist

    @property
    def image_extraction_timeout_ms(self):
        """Gets the image_extraction_timeout_ms of this ServerConfiguration.  # noqa: E501


        :return: The image_extraction_timeout_ms of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._image_extraction_timeout_ms

    @image_extraction_timeout_ms.setter
    def image_extraction_timeout_ms(self, image_extraction_timeout_ms):
        """Sets the image_extraction_timeout_ms of this ServerConfiguration.


        :param image_extraction_timeout_ms: The image_extraction_timeout_ms of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._image_extraction_timeout_ms = image_extraction_timeout_ms

    @property
    def path_substitutions(self):
        """Gets the path_substitutions of this ServerConfiguration.  # noqa: E501


        :return: The path_substitutions of this ServerConfiguration.  # noqa: E501
        :rtype: list[PathSubstitution]
        """
        return self._path_substitutions

    @path_substitutions.setter
    def path_substitutions(self, path_substitutions):
        """Sets the path_substitutions of this ServerConfiguration.


        :param path_substitutions: The path_substitutions of this ServerConfiguration.  # noqa: E501
        :type: list[PathSubstitution]
        """

        self._path_substitutions = path_substitutions

    @property
    def uninstalled_plugins(self):
        """Gets the uninstalled_plugins of this ServerConfiguration.  # noqa: E501


        :return: The uninstalled_plugins of this ServerConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._uninstalled_plugins

    @uninstalled_plugins.setter
    def uninstalled_plugins(self, uninstalled_plugins):
        """Sets the uninstalled_plugins of this ServerConfiguration.


        :param uninstalled_plugins: The uninstalled_plugins of this ServerConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._uninstalled_plugins = uninstalled_plugins

    @property
    def collapse_video_folders(self):
        """Gets the collapse_video_folders of this ServerConfiguration.  # noqa: E501


        :return: The collapse_video_folders of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._collapse_video_folders

    @collapse_video_folders.setter
    def collapse_video_folders(self, collapse_video_folders):
        """Sets the collapse_video_folders of this ServerConfiguration.


        :param collapse_video_folders: The collapse_video_folders of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._collapse_video_folders = collapse_video_folders

    @property
    def enable_original_track_titles(self):
        """Gets the enable_original_track_titles of this ServerConfiguration.  # noqa: E501


        :return: The enable_original_track_titles of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_original_track_titles

    @enable_original_track_titles.setter
    def enable_original_track_titles(self, enable_original_track_titles):
        """Sets the enable_original_track_titles of this ServerConfiguration.


        :param enable_original_track_titles: The enable_original_track_titles of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_original_track_titles = enable_original_track_titles

    @property
    def vacuum_database_on_startup(self):
        """Gets the vacuum_database_on_startup of this ServerConfiguration.  # noqa: E501


        :return: The vacuum_database_on_startup of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._vacuum_database_on_startup

    @vacuum_database_on_startup.setter
    def vacuum_database_on_startup(self, vacuum_database_on_startup):
        """Sets the vacuum_database_on_startup of this ServerConfiguration.


        :param vacuum_database_on_startup: The vacuum_database_on_startup of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._vacuum_database_on_startup = vacuum_database_on_startup

    @property
    def simultaneous_stream_limit(self):
        """Gets the simultaneous_stream_limit of this ServerConfiguration.  # noqa: E501


        :return: The simultaneous_stream_limit of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._simultaneous_stream_limit

    @simultaneous_stream_limit.setter
    def simultaneous_stream_limit(self, simultaneous_stream_limit):
        """Sets the simultaneous_stream_limit of this ServerConfiguration.


        :param simultaneous_stream_limit: The simultaneous_stream_limit of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._simultaneous_stream_limit = simultaneous_stream_limit

    @property
    def database_cache_size_mb(self):
        """Gets the database_cache_size_mb of this ServerConfiguration.  # noqa: E501


        :return: The database_cache_size_mb of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._database_cache_size_mb

    @database_cache_size_mb.setter
    def database_cache_size_mb(self, database_cache_size_mb):
        """Sets the database_cache_size_mb of this ServerConfiguration.


        :param database_cache_size_mb: The database_cache_size_mb of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._database_cache_size_mb = database_cache_size_mb

    @property
    def enable_sq_lite_mmio(self):
        """Gets the enable_sq_lite_mmio of this ServerConfiguration.  # noqa: E501


        :return: The enable_sq_lite_mmio of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_sq_lite_mmio

    @enable_sq_lite_mmio.setter
    def enable_sq_lite_mmio(self, enable_sq_lite_mmio):
        """Sets the enable_sq_lite_mmio of this ServerConfiguration.


        :param enable_sq_lite_mmio: The enable_sq_lite_mmio of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_sq_lite_mmio = enable_sq_lite_mmio

    @property
    def playlists_upgraded_to_m3_u(self):
        """Gets the playlists_upgraded_to_m3_u of this ServerConfiguration.  # noqa: E501


        :return: The playlists_upgraded_to_m3_u of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._playlists_upgraded_to_m3_u

    @playlists_upgraded_to_m3_u.setter
    def playlists_upgraded_to_m3_u(self, playlists_upgraded_to_m3_u):
        """Sets the playlists_upgraded_to_m3_u of this ServerConfiguration.


        :param playlists_upgraded_to_m3_u: The playlists_upgraded_to_m3_u of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._playlists_upgraded_to_m3_u = playlists_upgraded_to_m3_u

    @property
    def image_extractor_upgraded1(self):
        """Gets the image_extractor_upgraded1 of this ServerConfiguration.  # noqa: E501


        :return: The image_extractor_upgraded1 of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._image_extractor_upgraded1

    @image_extractor_upgraded1.setter
    def image_extractor_upgraded1(self, image_extractor_upgraded1):
        """Sets the image_extractor_upgraded1 of this ServerConfiguration.


        :param image_extractor_upgraded1: The image_extractor_upgraded1 of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._image_extractor_upgraded1 = image_extractor_upgraded1

    @property
    def enable_people_letter_sub_folders(self):
        """Gets the enable_people_letter_sub_folders of this ServerConfiguration.  # noqa: E501


        :return: The enable_people_letter_sub_folders of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_people_letter_sub_folders

    @enable_people_letter_sub_folders.setter
    def enable_people_letter_sub_folders(self, enable_people_letter_sub_folders):
        """Sets the enable_people_letter_sub_folders of this ServerConfiguration.


        :param enable_people_letter_sub_folders: The enable_people_letter_sub_folders of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_people_letter_sub_folders = enable_people_letter_sub_folders

    @property
    def optimize_database_on_shutdown(self):
        """Gets the optimize_database_on_shutdown of this ServerConfiguration.  # noqa: E501


        :return: The optimize_database_on_shutdown of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._optimize_database_on_shutdown

    @optimize_database_on_shutdown.setter
    def optimize_database_on_shutdown(self, optimize_database_on_shutdown):
        """Sets the optimize_database_on_shutdown of this ServerConfiguration.


        :param optimize_database_on_shutdown: The optimize_database_on_shutdown of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._optimize_database_on_shutdown = optimize_database_on_shutdown

    @property
    def database_analysis_limit(self):
        """Gets the database_analysis_limit of this ServerConfiguration.  # noqa: E501


        :return: The database_analysis_limit of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._database_analysis_limit

    @database_analysis_limit.setter
    def database_analysis_limit(self, database_analysis_limit):
        """Sets the database_analysis_limit of this ServerConfiguration.


        :param database_analysis_limit: The database_analysis_limit of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._database_analysis_limit = database_analysis_limit

    @property
    def disable_async_io(self):
        """Gets the disable_async_io of this ServerConfiguration.  # noqa: E501


        :return: The disable_async_io of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._disable_async_io

    @disable_async_io.setter
    def disable_async_io(self, disable_async_io):
        """Sets the disable_async_io of this ServerConfiguration.


        :param disable_async_io: The disable_async_io of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._disable_async_io = disable_async_io

    @property
    def migrated_to_user_item_shares8(self):
        """Gets the migrated_to_user_item_shares8 of this ServerConfiguration.  # noqa: E501


        :return: The migrated_to_user_item_shares8 of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._migrated_to_user_item_shares8

    @migrated_to_user_item_shares8.setter
    def migrated_to_user_item_shares8(self, migrated_to_user_item_shares8):
        """Sets the migrated_to_user_item_shares8 of this ServerConfiguration.


        :param migrated_to_user_item_shares8: The migrated_to_user_item_shares8 of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._migrated_to_user_item_shares8 = migrated_to_user_item_shares8

    @property
    def migrated_library_options_to_db(self):
        """Gets the migrated_library_options_to_db of this ServerConfiguration.  # noqa: E501


        :return: The migrated_library_options_to_db of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._migrated_library_options_to_db

    @migrated_library_options_to_db.setter
    def migrated_library_options_to_db(self, migrated_library_options_to_db):
        """Sets the migrated_library_options_to_db of this ServerConfiguration.


        :param migrated_library_options_to_db: The migrated_library_options_to_db of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._migrated_library_options_to_db = migrated_library_options_to_db

    @property
    def allow_legacy_local_network_password(self):
        """Gets the allow_legacy_local_network_password of this ServerConfiguration.  # noqa: E501


        :return: The allow_legacy_local_network_password of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._allow_legacy_local_network_password

    @allow_legacy_local_network_password.setter
    def allow_legacy_local_network_password(self, allow_legacy_local_network_password):
        """Sets the allow_legacy_local_network_password of this ServerConfiguration.


        :param allow_legacy_local_network_password: The allow_legacy_local_network_password of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._allow_legacy_local_network_password = allow_legacy_local_network_password

    @property
    def enable_saved_metadata_for_people(self):
        """Gets the enable_saved_metadata_for_people of this ServerConfiguration.  # noqa: E501


        :return: The enable_saved_metadata_for_people of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_saved_metadata_for_people

    @enable_saved_metadata_for_people.setter
    def enable_saved_metadata_for_people(self, enable_saved_metadata_for_people):
        """Sets the enable_saved_metadata_for_people of this ServerConfiguration.


        :param enable_saved_metadata_for_people: The enable_saved_metadata_for_people of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_saved_metadata_for_people = enable_saved_metadata_for_people

    @property
    def tv_channels_refreshed(self):
        """Gets the tv_channels_refreshed of this ServerConfiguration.  # noqa: E501


        :return: The tv_channels_refreshed of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._tv_channels_refreshed

    @tv_channels_refreshed.setter
    def tv_channels_refreshed(self, tv_channels_refreshed):
        """Sets the tv_channels_refreshed of this ServerConfiguration.


        :param tv_channels_refreshed: The tv_channels_refreshed of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._tv_channels_refreshed = tv_channels_refreshed

    @property
    def proxy_header_mode(self):
        """Gets the proxy_header_mode of this ServerConfiguration.  # noqa: E501


        :return: The proxy_header_mode of this ServerConfiguration.  # noqa: E501
        :rtype: ProxyHeaderMode
        """
        return self._proxy_header_mode

    @proxy_header_mode.setter
    def proxy_header_mode(self, proxy_header_mode):
        """Sets the proxy_header_mode of this ServerConfiguration.


        :param proxy_header_mode: The proxy_header_mode of this ServerConfiguration.  # noqa: E501
        :type: ProxyHeaderMode
        """

        self._proxy_header_mode = proxy_header_mode

    @property
    def enable_debug_level_logging(self):
        """Gets the enable_debug_level_logging of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[enable debug level logging\\].  # noqa: E501

        :return: The enable_debug_level_logging of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_debug_level_logging

    @enable_debug_level_logging.setter
    def enable_debug_level_logging(self, enable_debug_level_logging):
        """Sets the enable_debug_level_logging of this ServerConfiguration.

        A value indicating whether \\[enable debug level logging\\].  # noqa: E501

        :param enable_debug_level_logging: The enable_debug_level_logging of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_debug_level_logging = enable_debug_level_logging

    @property
    def revert_debug_logging(self):
        """Gets the revert_debug_logging of this ServerConfiguration.  # noqa: E501


        :return: The revert_debug_logging of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._revert_debug_logging

    @revert_debug_logging.setter
    def revert_debug_logging(self, revert_debug_logging):
        """Sets the revert_debug_logging of this ServerConfiguration.


        :param revert_debug_logging: The revert_debug_logging of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._revert_debug_logging = revert_debug_logging

    @property
    def enable_auto_update(self):
        """Gets the enable_auto_update of this ServerConfiguration.  # noqa: E501

        Enable automatically and silently updating of the application  # noqa: E501

        :return: The enable_auto_update of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_auto_update

    @enable_auto_update.setter
    def enable_auto_update(self, enable_auto_update):
        """Sets the enable_auto_update of this ServerConfiguration.

        Enable automatically and silently updating of the application  # noqa: E501

        :param enable_auto_update: The enable_auto_update of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_auto_update = enable_auto_update

    @property
    def log_file_retention_days(self):
        """Gets the log_file_retention_days of this ServerConfiguration.  # noqa: E501

        The number of days we should retain log files  # noqa: E501

        :return: The log_file_retention_days of this ServerConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._log_file_retention_days

    @log_file_retention_days.setter
    def log_file_retention_days(self, log_file_retention_days):
        """Sets the log_file_retention_days of this ServerConfiguration.

        The number of days we should retain log files  # noqa: E501

        :param log_file_retention_days: The log_file_retention_days of this ServerConfiguration.  # noqa: E501
        :type: int
        """

        self._log_file_retention_days = log_file_retention_days

    @property
    def run_at_startup(self):
        """Gets the run_at_startup of this ServerConfiguration.  # noqa: E501

        A value indicating whether \\[run at startup\\].  # noqa: E501

        :return: The run_at_startup of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._run_at_startup

    @run_at_startup.setter
    def run_at_startup(self, run_at_startup):
        """Sets the run_at_startup of this ServerConfiguration.

        A value indicating whether \\[run at startup\\].  # noqa: E501

        :param run_at_startup: The run_at_startup of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._run_at_startup = run_at_startup

    @property
    def is_startup_wizard_completed(self):
        """Gets the is_startup_wizard_completed of this ServerConfiguration.  # noqa: E501

        A value indicating whether this instance is first run.  # noqa: E501

        :return: The is_startup_wizard_completed of this ServerConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_startup_wizard_completed

    @is_startup_wizard_completed.setter
    def is_startup_wizard_completed(self, is_startup_wizard_completed):
        """Sets the is_startup_wizard_completed of this ServerConfiguration.

        A value indicating whether this instance is first run.  # noqa: E501

        :param is_startup_wizard_completed: The is_startup_wizard_completed of this ServerConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_startup_wizard_completed = is_startup_wizard_completed

    @property
    def cache_path(self):
        """Gets the cache_path of this ServerConfiguration.  # noqa: E501

        The cache path.  # noqa: E501

        :return: The cache_path of this ServerConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._cache_path

    @cache_path.setter
    def cache_path(self, cache_path):
        """Sets the cache_path of this ServerConfiguration.

        The cache path.  # noqa: E501

        :param cache_path: The cache_path of this ServerConfiguration.  # noqa: E501
        :type: str
        """

        self._cache_path = cache_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServerConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ApiOnPlaybackProgress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'playlist_index': 'int',
        'playlist_length': 'int',
        'shuffle': 'bool',
        'event_name': 'ProgressEvent'
    }

    attribute_map = {
        'playlist_index': 'PlaylistIndex',
        'playlist_length': 'PlaylistLength',
        'shuffle': 'Shuffle',
        'event_name': 'EventName'
    }

    def __init__(self, playlist_index=None, playlist_length=None, shuffle=None, event_name=None):  # noqa: E501
        """ApiOnPlaybackProgress - a model defined in Swagger"""  # noqa: E501
        self._playlist_index = None
        self._playlist_length = None
        self._shuffle = None
        self._event_name = None
        self.discriminator = None
        if playlist_index is not None:
            self.playlist_index = playlist_index
        if playlist_length is not None:
            self.playlist_length = playlist_length
        if shuffle is not None:
            self.shuffle = shuffle
        if event_name is not None:
            self.event_name = event_name

    @property
    def playlist_index(self):
        """Gets the playlist_index of this ApiOnPlaybackProgress.  # noqa: E501


        :return: The playlist_index of this ApiOnPlaybackProgress.  # noqa: E501
        :rtype: int
        """
        return self._playlist_index

    @playlist_index.setter
    def playlist_index(self, playlist_index):
        """Sets the playlist_index of this ApiOnPlaybackProgress.


        :param playlist_index: The playlist_index of this ApiOnPlaybackProgress.  # noqa: E501
        :type: int
        """

        self._playlist_index = playlist_index

    @property
    def playlist_length(self):
        """Gets the playlist_length of this ApiOnPlaybackProgress.  # noqa: E501


        :return: The playlist_length of this ApiOnPlaybackProgress.  # noqa: E501
        :rtype: int
        """
        return self._playlist_length

    @playlist_length.setter
    def playlist_length(self, playlist_length):
        """Sets the playlist_length of this ApiOnPlaybackProgress.


        :param playlist_length: The playlist_length of this ApiOnPlaybackProgress.  # noqa: E501
        :type: int
        """

        self._playlist_length = playlist_length

    @property
    def shuffle(self):
        """Gets the shuffle of this ApiOnPlaybackProgress.  # noqa: E501


        :return: The shuffle of this ApiOnPlaybackProgress.  # noqa: E501
        :rtype: bool
        """
        return self._shuffle

    @shuffle.setter
    def shuffle(self, shuffle):
        """Sets the shuffle of this ApiOnPlaybackProgress.


        :param shuffle: The shuffle of this ApiOnPlaybackProgress.  # noqa: E501
        :type: bool
        """

        self._shuffle = shuffle

    @property
    def event_name(self):
        """Gets the event_name of this ApiOnPlaybackProgress.  # noqa: E501


        :return: The event_name of this ApiOnPlaybackProgress.  # noqa: E501
        :rtype: ProgressEvent
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this ApiOnPlaybackProgress.


        :param event_name: The event_name of this ApiOnPlaybackProgress.  # noqa: E501
        :type: ProgressEvent
        """

        self._event_name = event_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiOnPlaybackProgress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiOnPlaybackProgress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
